pecos.qeclib.steane.preps.pauli\_states
=======================================

.. automodule:: pecos.qeclib.steane.preps.pauli_states











   .. rubric:: Classes

   .. autosummary::

      LogZeroRot
      PrepEncodingFTZero
      PrepEncodingNonFTZero
      PrepRUS
      PrepZeroVerify
